<?php
namespace Plugin\Controller;

use Plugin\DBMS\Manager;
use Plugin\Server\Response;
use Plugin\Server\Request;
use App\Config\Settings;
use Plugin\Exception\Error;
class Container {
	
	/**
	 * Slot variables can store values to be accessed inside any view:
	 * Key => Value
	 * @var mixed
	 */
	public static $slots = array();
	
	public static $services = array();
	private $serviceClasses = array();
	
	protected function setSlots($name,$value){
		self::$slots[$name] = $value;
	}
	
	/**
	 * Get the database Manager
	 * @return \Plugin\DBMS\Manager
	 */
	public function getManager(){
		return Manager::getManager();
	}
	
	protected function render($path,$vars = array()){
		$res = new Response();
		$res->setTemplate($path,$vars);
		return $res;
	}
	
	/**
	 * Get the request object
	 * @return \Plugin\Server\Request
	 */
	public function getRequest(){
		return Request::getRequest();
	}
	
	public function get($service){
		return $this->getService($service);
	}
	
	private function getService($name){
		if (isset(self::$services[$name])){
			return self::$services[$name];
		}
		$this->initiateServices();
		
		if (!isset($this->serviceClasses[$name])){
			Error::throw500("The service '$name' does not exist");
		}
		return $this->instantiate($this->serviceClasses[$name]["class"]);
	}
	
	private function initiateServices(){
		if (!empty($this->serviceClasses)){
			return;
		}
		$apps = Settings::getAppsInfo();
		$allServices = array();
		foreach($apps as $name => $ressources){
			foreach($ressources as $res){
				$path = ROOT_DIR."src/$name/$res/Config/service.php";
				if (file_exists($path)){
					include $path;
					$allServices = array_merge($allServices,$services);
				}
			}
		}
		$this->serviceClasses = $allServices;
	}
	
	private function instantiate($string){
		list($app,$section,$type,$name) = explode(":", $string);
		$className = "src\\$app\\$section\\$type\\$name";
		return new $className();
	}
}