<?php

namespace Plugin\Server;

use Plugin\Exception\Error;

class UploadedFile {
	
	private $filename;
	private $filetype;
	private $tmpname;
	private $error;
	private $filesize;
	private $newpath;
	private $isSaved;
	
	/**
	 * Uploaded File Object
	 * @param array $filearray From the $_FILES array
	 */
	public function __construct($filearray){
		$this->filename = $filearray['name'];
		$this->tmpname = $filearray['tmp_name'];
		$this->error = $filearray['error'];
		$this->filesize = $filearray['size'];
		
		$type = substr($this->filename,strrpos($this->filename,".")+1);
		if ($type)
			$this->filetype = $type;
		
		$this->isSaved = false;
	}
	
	/**
	 * the uploaded file original name
	 * @return string $filename
	 */
	public function getFilename() {
		return $this->filename;
	}

	/**
	 * if the file has any type return it or false
	 * @return string $filetype
	 */
	public function getFiletype() {
		return $this->filetype;
	}

	/**
	 * the temporary path and name of the file on the server
	 * @return string $tmpname
	 */
	public function getTmpname() {
		return $this->tmpname;
	}

	/**
	 * if there is any error or return 0
	 * @return integer $error
	 */
	public function getError() {
		return $this->error;
	}

	/**
	 * The current size in bytes
	 * @return integer $filesize
	 */
	public function getFilesize() {
		return $this->filesize;
	}

	
	public function setFilePath($name){
		$this->newpath = $name;
	}
	
	public function getFilePath(){
		return $this->newpath;
	}
	
	public function save(){
		if (!empty($this->newpath)){
			$this->createDir($this->newpath);
			if (file_exists(dirname($this->newpath))){
				$result = move_uploaded_file($this->tmpname, $this->newpath);
				if ($result){
					$this->isSaved = true;
				}
			}else {
				Error::throw500("Failed saving file $this->newpath");
			}
		}else {
			Error::throw500("no path selected for the uploaded file: $this->filename");
		}
	}
	
	public function isSaved(){
		return $this->isSaved;
	}
	
	
	public function createDir($path){
		$dirname = dirname($path);
		if (is_dir($dirname)){
			return true;
		}
		
		$result = mkdir($dirname,0777,true);
		if (!$result){
			Error::throw500("Could not create Directory: $dirname");
		}
		return true;
	}
}