<?php
namespace  src\Blog\Model\Interaction;

use Plugin\DBMS\Interaction;
use Plugin\Server\Request;
/**
 * CREATE  TABLE `scratchblog`.`file_manager` (
  `file_id` INT NOT NULL AUTO_INCREMENT ,
  `title` VARCHAR(200) NULL ,
  `path` VARCHAR(250) NULL ,
  `type` VARCHAR(45) NULL ,
  `description` VARCHAR(400) NULL ,
  `date_added` DATETIME NULL ,
  PRIMARY KEY (`file_id`) );
 * @author ibrahim
 *
 */
class FileDataManager extends Interaction {
	
	
	protected $table_name = "file";
	protected $table_id = "file_id";
	
	const UPLOAD_REAL_PATH = "/var/www/scratchupload/";
	const UPLOAD_PATH = "/uploads/";
	
	/**
	 * Get All files uploaded
	 * @param int $limit
	 * @param int $page
	 * @return \stdclass Array Collection 
	 */
	public function fetchFiles($limit,$page){
		$offset = ($page - 1)*$limit;
		$sql = "SELECT * FROM file
				ORDER BY date_added DESC
				LIMIT %d,%d";
		$sql = sprintf($sql,
				(int) $offset,
				(int) $limit
				);
		return $this->simplyQuery($sql);
	}
	
	/**
	 * Get the Total file uploaded count
	 * @return int $count
	 */
	public function totalFileCount(){
		$sql = "SELECT count(file_id) as total FROM file;";
		$count = $this->simplyQuery($sql);
		return $count[0]->total;
	}
	
	/**
	 * Save the file and create Path
	 * @param Request $req
	 */
	public function saveFile($req){
		$title = $req->getParam("title");
		$description = $req->getParam("description");
		$date_added = date("Y-m-d H:i:s");
		
		$sql = "INSERT INTO file (title,description,path,type,date_added)
			VALUES ('%s','%s','%s','%s','%s')	
			";
		
		
		$file = $req->getFiles("file");
		
		$filename = $file->getFilename();
		$path = self::UPLOAD_REAL_PATH.date("Y")."/".$this->sanitizeInput($filename);
		$file->setFilePath($path);
		$file->save();
		$type = $file->getFiletype();
		$webpath = str_replace(self::UPLOAD_REAL_PATH, self::UPLOAD_PATH, $path);
		
		$sql = sprintf($sql,
				$this->escape($title),
				$this->escape($description),
				$this->escape($webpath),
				$this->escape($type),
				$this->escape($date_added)
		);
		
		return $this->getManager()->execSQL($sql);
	}
	
	
	private function sanitizeInput($filename){
		$string = preg_replace("/[^a-zA-Z0-9]\.\-/", "_", $filename);
		$string = preg_replace("/(\s+)|(_+)/", "_", $string);
		return $string;
	}
}